@@ -15,7 +15,7 @@
 #define INET_ERR_HNR     -2  /*!< \brief Host name resolution failed */
 #define INET_ERR_SNR     -3  /*!< \brief Service name resolution failed */
 #define INET_ERR_AF      -4  /*!< \brief Address family not supported */
-#define INET_ERR_SOCK    -5  /*!< \brief Socket creation failed */
+#define INET_ERR_SOCK    -5  /*!< \brief Socket creation/configuration failed */
 #define INET_ERR_CONN    -6  /*!< \brief Connection failed */
 #define INET_ERR_BADF    -7  /*!< \brief Invalid socket descriptor */
 #define INET_ERR_RX_TO   -8  /*!< \brief Setting RX timeout failed */
