@@ -167,6 +167,10 @@ int  posix_fsync(int);
 /* ========================================================================== */
 /* Environment and return values */
 
+/* Pointer to array with environment variables */
+extern char**  environ;
+#define posix_environ  environ
+
 /* Standard return values for processes */
 #define POSIX_EXIT_SUCCESS  EXIT_SUCCESS
 #define POSIX_EXIT_FAILURE  EXIT_FAILURE
@@ -256,9 +260,13 @@ int  posix_fsync(int);
 /* Time */
 
 #define posix_time_t  time_t
+#define struct_posix_tm  struct tm
 
 #define posix_time  time
 
+#define posix_gmtime_r  gmtime_r
+#define posix_localtime_r  localtime_r
+
 /* The %z conversion was included into POSIX.1 since Issue 6 */
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
 #  define posix_strftime  strftime
